export const description =
  'On this page, we`ll take a look at the future roadmap for Robyn.'


- Add performance optimizations
- OpenAPI Integration
- Pydantic Integration
- Implement Auto Const Requests
- Add ORM support, especially Prisma integration    
- Improve Plugin Ecosystem
- Better Documentation
- Improve the Websockets
- Template Support
- Graphql integration with Strawberry
- Invest more time in the community around Robyn.

## Next Steps

- [Advanced Features](/documentation/api_reference/advanced_features)
